summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/ui/kopeteview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/ui/kopeteview.h')
-rw-r--r--kopete/libkopete/ui/kopeteview.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kopete/libkopete/ui/kopeteview.h b/kopete/libkopete/ui/kopeteview.h
index 47320546..c54b1dba 100644
--- a/kopete/libkopete/ui/kopeteview.h
+++ b/kopete/libkopete/ui/kopeteview.h
@@ -20,7 +20,7 @@
#define KOPETEVIEW_H
#include "kopetemessage.h"
-#include <qvaluelist.h>
+#include <tqvaluelist.h>
#include "kopete_export.h"
namespace Kopete
@@ -79,7 +79,7 @@ class KOPETE_EXPORT KopeteView
*
* The default implementation just call @ref appendMessage() X times
*/
- virtual void appendMessages( QValueList<Kopete::Message> );
+ virtual void appendMessages( TQValueList<Kopete::Message> );
/**
* @brief Raises the view above other windows
@@ -115,12 +115,12 @@ class KOPETE_EXPORT KopeteView
*
* Can be reimplemented to return this if derived object is a widget
*/
- virtual QWidget *mainWidget() = 0;
+ virtual TQWidget *mainWidget() = 0;
/**
* @brief Inform the view the message was sent successfully
*
- * This should be reimplemented as a SLOT in any derived objects
+ * This should be reimplemented as a TQT_SLOT in any derived objects
*/
virtual void messageSentSuccessfully() = 0;
@@ -135,10 +135,10 @@ class KOPETE_EXPORT KopeteView
* A view does not need to implement this method unless they have context
* menus that can be extended
*
* @param target A target QObject for the contextMenuEvent signal of the view
* @param slot A slot that matches the signature ( QString&, KPopupMenu *)
*/
- virtual void registerContextMenuHandler( QObject *target, const char*slot ){ Q_UNUSED(target); Q_UNUSED(slot); };
+ virtual void registerContextMenuHandler( TQObject *target, const char*slot ){ Q_UNUSED(target); Q_UNUSED(slot); };
/**
* @brief Register a handler for the tooltip
@@ -151,10 +151,10 @@ class KOPETE_EXPORT KopeteView
* A view does not need to impliment this method unless it has the ability
* to show tooltips
*
* @param target A target QObject for the contextMenuEvent signal of the view
* @param slot A slot that matches the signature ( QString&, KPopupMenu *)
*/
- virtual void registerTooltipHandler( QObject *target, const char*slot ){ Q_UNUSED(target); Q_UNUSED(slot); };
+ virtual void registerTooltipHandler( TQObject *target, const char*slot ){ Q_UNUSED(target); Q_UNUSED(slot); };
/**
* @brief Returns the Kopete::ViewPlugin responsible for this view
@@ -135,10 +135,10 @@ class KOPETE_EXPORT KopeteView
* menus that can be extended
*
- * @param target A target QObject for the contextMenuEvent signal of the view
- * @param slot A slot that matches the signature ( QString&, KPopupMenu *)
+ * @param target A target TQObject for the contextMenuEvent signal of the view
+ * @param slot A slot that matches the signature ( TQString&, KPopupMenu *)
*/
@@ -151,10 +151,10 @@ class KOPETE_EXPORT KopeteView
* to show tooltips
*
- * @param target A target QObject for the contextMenuEvent signal of the view
- * @param slot A slot that matches the signature ( QString&, KPopupMenu *)
+ * @param target A target TQObject for the contextMenuEvent signal of the view
+ * @param slot A slot that matches the signature ( TQString&, KPopupMenu *)
*/